import { NextResponse } from 'next/server'

if (!process.env.API_URL) {
  throw new Error('API_URL is not defined in environment variables')
}

if (!process.env.ADMIN_KEY) {
  throw new Error('ADMIN_KEY is not defined in environment variables')
}

export async function GET(
  request: Request,
  { params }: { params: { keyId: string } }
) {
  try {
    const { keyId } = params
    const url = `${process.env.API_URL}/api/v1/denylist/admin/api-keys/${keyId}/details`
    
    console.log('🚀 Making request to:', url)
    console.log('🔑 With headers:', {
      'Content-Type': 'application/json',
      'Accept': 'application/json',
      'X-Admin-Key': process.env.ADMIN_KEY?.substring(0, 10) + '...',
    })
    
    const response = await fetch(url, {
      method: 'GET',
      headers: {
        'Content-Type': 'application/json',
        'Accept': 'application/json',
        'X-Admin-Key': process.env.ADMIN_KEY as string,
      },
    })

    console.log('📥 Response status:', response.status)
    console.log('📤 Response headers:', Object.fromEntries(response.headers.entries()))

    if (!response.ok) {
      const errorText = await response.text()
      console.error('❌ API Error Response:', {
        status: response.status,
        statusText: response.statusText,
        body: errorText
      })
      return NextResponse.json(
        { 
          success: false, 
          message: `Server error: ${response.status} - ${errorText}`,
          data: null
        },
        { status: response.status }
      )
    }

    const rawText = await response.text()
    console.log('📦 Raw response:', rawText)

    let data
    try {
      data = JSON.parse(rawText)
      console.log('✅ Parsed response data:', data)
    } catch (parseError) {
      console.error('❌ JSON Parse Error:', parseError)
      throw new Error(`Failed to parse response: ${rawText}`)
    }
    
    if (!data.success) {
      console.error('❌ API returned failure:', data)
      return NextResponse.json(
        { 
          success: false, 
          message: data.message || 'Failed to fetch API key details',
          data: null
        },
        { status: 400 }
      )
    }
    
    return NextResponse.json(data)
  } catch (error) {
    console.error('❌ Detailed API Error:', {
      error,
      message: error instanceof Error ? error.message : 'Unknown error',
      stack: error instanceof Error ? error.stack : undefined
    })

    return NextResponse.json(
      { 
        success: false, 
        message: error instanceof Error 
          ? `Server error: ${error.message}` 
          : 'An unexpected error occurred while fetching API key details',
        data: null
      },
      { status: 500 }
    )
  }
} 