'use client'

import { useState, useEffect } from 'react'
import { Download, Key, LayoutDashboard, LogOut,} from 'lucide-react'
import Image from 'next/image'

import { Button } from '@/components/ui/button'
import {
  DropdownMenu,
  DropdownMenuContent,
  DropdownMenuItem,
  DropdownMenuLabel,
  DropdownMenuSeparator,
} from '@/components/ui/dropdown-menu'

import { StatsCards } from '@/components/dashboard/StatsCards'
import { ApiKeysTable } from '@/components/dashboard/ApiKeysTable'
import { DashboardCharts } from '@/components/dashboard/DashboardCharts'
import { LoginForm } from '@/components/dashboard/LoginForm'
import { ApiKeyDetails } from '@/components/dashboard/ApiKeyDetails'
import { ApiKey } from '@/types/api'
import { useToast } from "@/components/ui/use-toast"

interface ThresholdData {
  threshold: string;
  total_requests: number;
  unique_keys: number;
  last_used: string;
  percentage: string;
}

interface ApiResponse {
  success: boolean;
  data: ThresholdData[];
}

interface DailyRequest {
  date: string;
  'DNI': number;
  'DNI+51': number;
  'DNI+66': number;
  'DNI+80': number;
}

interface UsageByList {
  list: string;
  requests: number;
}

interface IpUsageData {
  ip_address: string;
  total_requests: number;
  requests_by_threshold: {
    '51%': number;
    '66%': number;
    '80%': number;
  };
  last_used: string;
}

export default function DashboardPage() {
  const { toast } = useToast()
  const [isAuthenticated, setIsAuthenticated] = useState<boolean | null>(null)
  const [username, setUsername] = useState('')
  const [password, setPassword] = useState('')
  const [error, setError] = useState('')
  const [mounted, setMounted] = useState(false)
  const [activeTab, setActiveTab] = useState('dashboard')
  const [selectedApiKey, setSelectedApiKey] = useState<ApiKey | null>(null)
  const [apiKeys, setApiKeys] = useState<ApiKey[]>([])
  const [isLoading, setIsLoading] = useState(true)
  const [thresholdUsage, setThresholdUsage] = useState<ThresholdData[]>([]);
  const [dailyRequests, setDailyRequests] = useState<DailyRequest[]>([]);
  const [apiUsageByList, setApiUsageByList] = useState<UsageByList[]>([]);
  const [topIpAddresses, setTopIpAddresses] = useState<IpUsageData[]>([]);

  useEffect(() => {
    setMounted(true)
    // Check for authentication status from localStorage or session
    const authStatus = localStorage.getItem('isAuthenticated') === 'true'
    setIsAuthenticated(authStatus)

    // Fetch API keys if authenticated
    if (authStatus) {
      fetchApiKeys()
      fetchThresholdUsage()
      fetchTopIpAddresses()
    }
  // eslint-disable-next-line react-hooks/exhaustive-deps
  }, [])

  useEffect(() => {
    if (thresholdUsage.length > 0) {
      // Transform threshold usage data for the apiUsageByList
      const transformedUsage = thresholdUsage.map(item => ({
        list: item.threshold === 'other' ? 'Custom' : `DNI+${item.threshold.replace('%', '')}`,
        requests: item.total_requests
      })).sort((a, b) => {
        if (a.list === 'DNI') return -1;
        if (b.list === 'DNI') return 1;
        return parseInt(a.list.replace('DNI+', '')) - parseInt(b.list.replace('DNI+', ''));
      });

      setApiUsageByList(transformedUsage);

      // Create dummy daily requests data until we have a proper endpoint
      // You should replace this with real data from an API endpoint
      const today = new Date();
      const dummyDailyData: DailyRequest[] = Array.from({ length: 5 }).map((_, index) => {
        const date = new Date(today);
        date.setDate(date.getDate() - index);
        const dateStr = date.toLocaleDateString('en-US', { 
          month: '2-digit', 
          day: '2-digit' 
        });

        return {
          date: dateStr,
          'DNI': thresholdUsage.find(t => t.threshold === 'other')?.total_requests || 0,
          'DNI+51': thresholdUsage.find(t => t.threshold === '51%')?.total_requests || 0,
          'DNI+66': thresholdUsage.find(t => t.threshold === '66%')?.total_requests || 0,
          'DNI+80': thresholdUsage.find(t => t.threshold === '80%')?.total_requests || 0,
        };
      }).reverse();

      setDailyRequests(dummyDailyData);
    }
  }, [thresholdUsage]);

  const fetchThresholdUsage = async () => {
    try {
      const response = await fetch('/api/dni-dash/admin/stats/threshold-usage');
      const data: ApiResponse = await response.json();
      
      if (!data.success) {
        throw new Error('Failed to fetch threshold usage data');
      }

      setThresholdUsage(data.data);
    } catch (err) {
      console.error('Error fetching threshold usage:', err);
      toast({
        title: "Error Fetching Usage Data",
        description: err instanceof Error ? err.message : 'Failed to fetch usage data',
        variant: "destructive",
      });
    } finally {
      setIsLoading(false);
    }
  };

  const fetchApiKeys = async () => {
    try {
      console.log('Fetching API keys...')
      const response = await fetch('/api/dni/keys')
      
      console.log('Response status:', response.status)
      
      if (!response.ok) {
        const errorText = await response.text()
        console.error('API Error Response:', errorText)
        
        let errorMessage: string
        try {
          const errorData = JSON.parse(errorText)
          errorMessage = errorData.message || `HTTP error! status: ${response.status}`
        } catch {
          errorMessage = `HTTP error! status: ${response.status} - ${errorText}`
        }
        
        throw new Error(errorMessage)
      }

      const responseData = await response.json()
      console.log('API Response data:', responseData)

      if (!responseData.success) {
        throw new Error(responseData.message || 'Failed to fetch API keys')
      }

      // Transform the API response to match our ApiKey interface
      // eslint-disable-next-line @typescript-eslint/no-explicit-any
      const transformedKeys: ApiKey[] = responseData.data.map((key: any) => ({
        id: key.key_id,
        key: key.key,
        client: key.description,
        permissions: key.permissions.map((perm: string) => {
          switch(perm) {
            case 'threshold_51': return 'DNI+51'
            case 'threshold_66': return 'DNI+66'
            case 'threshold_80': return 'DNI+80'
            default: return perm
          }
        }),
        requests: {
          ...key.threshold_requests,
          'Total': key.total_requests || 0,
        },
        lastUsed: key.last_used_at || key.created_at,
        is_active: key.is_active,
      }))

      setApiKeys(transformedKeys)
    } catch (error) {
      console.error('Detailed error:', {
        error,
        message: error instanceof Error ? error.message : 'Unknown error',
        stack: error instanceof Error ? error.stack : undefined
      })
      
      toast({
        title: "Error Fetching API Keys",
        description: error instanceof Error ? error.message : 'Failed to fetch API keys',
        variant: "destructive",
        duration: 5000,
      })
    } finally {
      setIsLoading(false)
    }
  }

  const handleLogin = (e: React.FormEvent) => {
    e.preventDefault()
    if (username === 'admin' && password === 'password') {
      setIsAuthenticated(true)
      localStorage.setItem('isAuthenticated', 'true')
      setError('')
    } else {
      setError('Invalid username or password')
    }
  }

  const handleLogout = () => {
    setIsAuthenticated(false)
    localStorage.removeItem('isAuthenticated')
    setUsername('')
    setPassword('')
  }

  const handleCreateKey = async ({ client, permissions }: { client: string; permissions: string[] }) => {
    try {
      const newKey: ApiKey = {
        id: apiKeys.length + 1,
        key: `sk_test_${Math.random().toString(36).substring(2, 15)}`,
        client,
        permissions,
        requests: {},
        lastUsed: new Date().toISOString().split('T')[0],
        is_active: true
      }
      
      apiKeys.push(newKey)
      console.log('Created new key:', newKey)

      // Refresh the API keys list after creating a new key
      await fetchApiKeys()
    } catch (error) {
      console.error('Error creating API key:', error)
      toast({
        title: "Error Creating API Key",
        description: error instanceof Error ? error.message : 'Failed to create API key',
        variant: "destructive",
      })
    }
  }

  // eslint-disable-next-line @typescript-eslint/no-unused-vars
  const handleRevokeKey = async (id: number) => {
    try {
      // Refresh the API keys list after revoking
      await fetchApiKeys()
    } catch (error) {
      console.error('Error after revoking key:', error)
    }
  }

  const handleSelectKey = (key: ApiKey) => {
    setSelectedApiKey(key)
  }

  const handleKeyToggle = (keyId: number, newStatus: boolean) => {
    // Update the selected API key status
    if (selectedApiKey && selectedApiKey.id === keyId) {
      setSelectedApiKey({
        ...selectedApiKey,
        isActive: newStatus
      });
    }
    
    // Update the key in the apiKeys array
    setApiKeys(apiKeys.map(key => 
      key.id === keyId 
        ? { ...key, isActive: newStatus }
        : key
    ));

    // Refresh the API keys in the background
    fetchApiKeys();
  }

  const fetchTopIpAddresses = async () => {
    try {
      const response = await fetch('/api/dni-dash/admin/stats/top-ips');
      const data = await response.json();
      
      if (!data.success) {
        throw new Error('Failed to fetch top IP addresses');
      }

      setTopIpAddresses(data.data);
    } catch (err) {
      console.error('Error fetching top IP addresses:', err);
      toast({
        title: "Error Fetching IP Data",
        description: err instanceof Error ? err.message : 'Failed to fetch IP data',
        variant: "destructive",
      });
    }
  };

  const renderContent = () => {
    if (selectedApiKey) {
      return (
        <ApiKeyDetails
          apiKey={selectedApiKey}
          onBack={() => setSelectedApiKey(null)}
          onDelete={() => {
            setSelectedApiKey(null);
            // Optionally refresh the API keys list
            fetchApiKeys();  // Assuming you have this function
          }}
          onToggle={handleKeyToggle}
        />
      )
    }

    switch (activeTab) {
      case 'api-keys':
        return (
          <ApiKeysTable
            apiKeys={apiKeys}
            onCreateKey={handleCreateKey}
            onRevokeKey={handleRevokeKey}
            onSelectKey={handleSelectKey}
          />
        )
      case 'dashboard':
      default:
        const totalDniRequests = thresholdUsage.find(t => t.threshold === 'other')?.total_requests || 0;
        const fiftyoneRequests = thresholdUsage.find(t => t.threshold === '51%')?.total_requests || 0;
        const enhancedRequests = thresholdUsage.find(t => t.threshold === '66%')?.total_requests || 0;
        const premiumRequests = thresholdUsage.find(t => t.threshold === '80%')?.total_requests || 0;

        return (
          <>
            <StatsCards
              totalKeys={apiKeys.length}
              dniRequests={totalDniRequests}
              fiftyonePercent={fiftyoneRequests}
              sixtysixPercent={enhancedRequests}
              eightyPercentRequests={premiumRequests}
            />
            <DashboardCharts
              dailyRequests={dailyRequests}
              apiUsageByList={apiUsageByList}
              topIpAddresses={topIpAddresses}
            />
            <ApiKeysTable
              apiKeys={apiKeys}
              onCreateKey={handleCreateKey}
              onRevokeKey={handleRevokeKey}
              onSelectKey={handleSelectKey}
            />
          </>
        )
    }
  }

  // Don't render anything until we've mounted
  if (!mounted) {
    return null
  }

  if (!isAuthenticated) {
    return (
      <LoginForm
        username={username}
        password={password}
        error={error}
        onUsernameChange={setUsername}
        onPasswordChange={setPassword}
        onSubmit={handleLogin}
      />
    )
  }

  return (
    <div className="min-h-screen bg-gray-50">
      <div className="flex">
        {/* Sidebar */}
        <div className="fixed flex h-screen w-64 flex-col border-r bg-white">
          <div className="flex h-16 items-center justify-center border-b px-6">
            <div className="relative h-12 w-24">
              <Image
                src="/favicon.webp"
                alt="IFTAS Logo"
                fill
                style={{ objectFit: 'contain' }}
                priority
              />
            </div>
          </div>
          <nav className="flex-1 space-y-1 p-4">
            <button
              onClick={() => {
                setActiveTab('dashboard');
                setSelectedApiKey(null);
              }}
              className={`flex w-full items-center gap-3 rounded-lg px-4 py-2 text-sm font-medium ${
                activeTab === 'dashboard' 
                  ? 'bg-gray-100' 
                  : 'text-gray-600 hover:bg-gray-100'
              }`}
            >
              <LayoutDashboard className="size-4" />
              Dashboard
            </button>
            {/* <button
              onClick={() => setActiveTab('api-keys')}
              className={`flex w-full items-center gap-3 rounded-lg px-4 py-2 text-sm font-medium ${
                activeTab === 'api-keys' 
                  ? 'bg-gray-100' 
                  : 'text-gray-600 hover:bg-gray-100'
              }`}
            >
              <Key className="size-4" />
              API Keys
            </button> */}
            {/* <button
              onClick={() => setActiveTab('notifications')}
              className={`flex w-full items-center gap-3 rounded-lg px-4 py-2 text-sm font-medium ${
                activeTab === 'notifications' 
                  ? 'bg-gray-100' 
                  : 'text-gray-600 hover:bg-gray-100'
              }`}
            >
              <Bell className="size-4" />
              Notifications
            </button>
            <button
              onClick={() => setActiveTab('settings')}
              className={`flex w-full items-center gap-3 rounded-lg px-4 py-2 text-sm font-medium ${
                activeTab === 'settings' 
                  ? 'bg-gray-100' 
                  : 'text-gray-600 hover:bg-gray-100'
              }`}
            >
              <Settings className="size-4" />
              Settings
            </button> */}
          </nav>
          <div className="border-t p-4">
            <Button
              variant="ghost"
              className="w-full justify-start gap-3 text-red-600 hover:bg-red-50 hover:text-red-600"
              onClick={handleLogout}
            >
              <LogOut className="size-4" />
              Sign Out
            </Button>
          </div>
        </div>

        {/* Main Content */}
        <main className="ml-64 flex-1 p-8">
          <div className="mb-8 flex items-center justify-between">
            <div>
              <h1 className="text-2xl font-bold">
                {activeTab === 'dashboard' && 'Dashboard Overview'}
                {activeTab === 'api-keys' && 'API Keys Management'}
                {activeTab === 'notifications' && 'Notifications'}
                {activeTab === 'settings' && 'Settings'}
              </h1>
              <p className="text-gray-600">
                {activeTab === 'dashboard' && 'Monitor your API usage and manage access keys'}
                {activeTab === 'api-keys' && 'Manage your API keys and permissions'}
                {activeTab === 'notifications' && 'View your notifications'}
                {activeTab === 'settings' && 'Configure your dashboard settings'}
              </p>
            </div>
            {activeTab === 'dashboard' && (
              <DropdownMenu>
                {/* <DropdownMenuTrigger asChild>
                  <Button>
                    <Download className="mr-2 h-4 w-4" />
                    Export
                  </Button>
                </DropdownMenuTrigger> */}
                <DropdownMenuContent align="end">
                  <DropdownMenuLabel>Choose format</DropdownMenuLabel>
                  <DropdownMenuSeparator />
                  <DropdownMenuItem>
                    <Download className="mr-2 h-4 w-4" />
                    CSV
                  </DropdownMenuItem>
                  <DropdownMenuItem>
                    <Download className="mr-2 h-4 w-4" />
                    JSON
                  </DropdownMenuItem>
                </DropdownMenuContent>
              </DropdownMenu>
            )}
          </div>

          {renderContent()}
        </main>
      </div>
    </div>
  )
}
