import React from 'react'
import { ArrowLeft, ChevronLeft, ChevronRight } from 'lucide-react'
import { Button } from '@/components/ui/button'
import { Card, CardContent, CardHeader, CardTitle } from '@/components/ui/card'
import { LineChart, Line, XAxis, YAxis, Tooltip, ResponsiveContainer, BarChart, Bar, Legend } from 'recharts'
import { useState, useEffect, Fragment } from 'react'
import { 
  AlertDialog,
  AlertDialogAction,
  AlertDialogCancel,
  AlertDialogContent,
  AlertDialogDescription,
  AlertDialogFooter,
  AlertDialogHeader,
  AlertDialogTitle,
} from "@/components/ui/alert-dialog"
import { useToast } from "@/components/ui/use-toast"
 
interface ApiKeyDetailsProps {
  apiKey: {
    id: number | string;
    key: string;
    client: string;
    permissions: string[];
    requests: {
      'DNI': number;
      'DNI+51': number;
      'DNI+66': number;
      'DNI+80': number;
      'Total': number;
    };
    lastUsed: string;
    isActive: boolean;
  };
  onBack: () => void;
  onDelete: () => void;
  onToggle: (keyId: number | string, newStatus: boolean) => void;
}

interface DailyStat {
  date: string;
  total_requests: number;
  threshold_51: number;
  threshold_66: number;
  threshold_80: number;
}

interface MonthlyStat {
  month: string;
  total_requests: number;
  threshold_51: number;
  threshold_66: number;
  threshold_80: number;
}

interface DetailedStat {
  timestamp: string;
  total_requests: number;
  threshold_51: number;
  threshold_66: number;
  threshold_80: number;
}

interface UserAgentStat {
  user_agent: string;
  count: number;
}

interface EndpointWithUserAgents {
  threshold: string;
  total: number;
  [key: string]: number | string;
}

interface IpAddressStat {
  ip_address: string;
  requests: number;
}

interface IpThresholdStat {
  ip_address: string;
  thresholds: {
    [key: string]: number;  // threshold -> request count
  };
  total_requests: number;
}

interface IpUserAgentStat {
  ip_address: string;
  user_agents: {
    [key: string]: number;  // user_agent -> request count
  };
  total_requests: number;
}

interface ApiKeyDetailsResponse {
  success: boolean;
  data: {
    api_key: {
      id: number;
      description: string;
      key: string;
      created_at: string;
      last_used_at: string;
      is_active: boolean;
      is_admin: boolean;
    };
    permissions: string[];
    threshold_usage: Record<string, {
      requests: number;
      last_used: string;
    }>;
    usage_stats: {
      total_requests: number;
      endpoints: Array<{
        endpoint: string;
        total_requests: number;
        last_used: string;
        unique_ips: number;
      }>;
      daily_stats: Array<{
        date: string;
        total_requests: number;
        unique_endpoints: number;
      }>;
      hourly_distribution: Array<{
        hour: number;
        total_requests: number;
      }>;
    };
    recent_requests: Array<{
      endpoint: string;
      method: string;
      timestamp: string;
      ip_address: string;
      user_agent: string;
    }>;
  };
}

interface PaginatedIpStats {
  ip_address: string;
  total_requests: number;
  threshold_51: number;
  threshold_66: number;
  threshold_80: number;
}

// Create a reusable custom tick component for numbers
const NumberTick = (props: any) => {
  const { x, y, payload } = props;
  // Remove all problematic props
  return (
    <g transform={`translate(${x},${y})`}>
      <text
        x={0}
        y={0}
        dy={4}
        textAnchor="end"
        fill="#666"
        fontSize={12}
        transform="rotate(0)"
      >
        {typeof payload.value === 'number' 
          ? payload.value.toLocaleString() 
          : payload.value}
      </text>
    </g>
  );
};

// Create a reusable custom tick component for IP addresses
const IPTick = (props: any) => {
  const { x, y, payload } = props;
  return (
    <g transform={`translate(${x},${y})`}>
      <text
        x={0}
        y={0}
        dy={4}
        textAnchor="end"
        fill="#666"
        fontSize={11}
        transform="rotate(-45)"
      >
        {payload.value.length > 15 
          ? `${payload.value.slice(0, 15)}...` 
          : payload.value}
      </text>
    </g>
  );
};

export function ApiKeyDetails({ apiKey, onBack, onDelete, onToggle }: ApiKeyDetailsProps) {
  const [totalRequests, setTotalRequests] = useState(0)
  const [viewMode, setViewMode] = useState<'detailed' | 'daily' | 'monthly'>('detailed')
  const [detailedUsage, setDetailedUsage] = useState<DetailedStat[]>([])
  const [dailyUsage, setDailyUsage] = useState<DailyStat[]>([])
  // @ts-ignore - setMonthlyUsage will be used later
  const [monthlyUsage, setMonthlyUsage] = useState<MonthlyStat[]>([])
  const [endpointStats, setEndpointStats] = useState<EndpointWithUserAgents[]>([])
  const [userAgentStats, setUserAgentStats] = useState<UserAgentStat[]>([])
  const [thresholdStats, setThresholdStats] = useState<Array<{
    threshold: string;
    requests: number;
  }>>([]);
  const [ipAddressStats, setIpAddressStats] = useState<IpAddressStat[]>([]);
  const [ipPageSize] = useState(10);
  const [showAllIPs, setShowAllIPs] = useState(false);
  const [ipThresholdStats, setIpThresholdStats] = useState<IpThresholdStat[]>([]);
  const [ipUserAgentStats, setIpUserAgentStats] = useState<IpUserAgentStat[]>([]);
  const [selectedIp, setSelectedIp] = useState<string | null>(null);
  const [showDeleteDialog, setShowDeleteDialog] = useState(false);
  const [isDeleting, setIsDeleting] = useState(false);
  const [isToggling, setIsToggling] = useState(false);
  const { toast } = useToast();
  const [currentPage, setCurrentPage] = useState(1);
  const [pageSize] = useState(10);
  const [paginatedIpStats, setPaginatedIpStats] = useState<PaginatedIpStats[]>([]);
  const [totalPages, setTotalPages] = useState(1);

  useEffect(() => {
    console.log('ApiKeyDetails received apiKey:', apiKey);
  }, [apiKey]);

  useEffect(() => {
    const fetchDetails = async () => {
      try {
        const response = await fetch(`/api/dni-dash/keys/${apiKey.id}/details`);
        const result: ApiKeyDetailsResponse = await response.json();
        
        console.log('Original apiKey.requests:', apiKey.requests);
        console.log('API response usage stats:', result.data.usage_stats);
        
        if (!response.ok) {
          throw new Error(`HTTP error! status: ${response.status}`);
        }
        
        if (!result.data) {
          console.error('Unexpected API response format:', result);
          return;
        }

        console.log('API Response:', result);

        if (result.data.threshold_usage) {
          console.log('Threshold usage data:', result.data.threshold_usage);
          const thresholdData = Object.entries(result.data.threshold_usage).map(([threshold, data]) => ({
            threshold: threshold.replace('threshold_', ''),
            requests: data.requests
          })).sort((a, b) => Number(a.threshold) - Number(b.threshold));
          
          console.log('Processed threshold data:', thresholdData);
          setThresholdStats(thresholdData);
        }

        if (result.data.usage_stats?.hourly_distribution) {
          const formattedDetailedStats = result.data.usage_stats.hourly_distribution.map(stat => {
            // Find requests for each threshold in this hour
            const threshold51 = result.data.recent_requests.filter(req => 
              req.endpoint.includes('threshold=51') && 
              new Date(req.timestamp).getHours() === stat.hour
            ).length;
            
            const threshold66 = result.data.recent_requests.filter(req => 
              req.endpoint.includes('threshold=66') && 
              new Date(req.timestamp).getHours() === stat.hour
            ).length;
            
            const threshold80 = result.data.recent_requests.filter(req => 
              req.endpoint.includes('threshold=80') && 
              new Date(req.timestamp).getHours() === stat.hour
            ).length;

            return {
              timestamp: `${stat.hour}:00`,
              total_requests: stat.total_requests,
              threshold_51: threshold51,
              threshold_66: threshold66,
              threshold_80: threshold80
            };
          });
          setDetailedUsage(formattedDetailedStats);
        }

        if (result.data.usage_stats?.daily_stats) {
          const formattedDailyStats = result.data.usage_stats.daily_stats.map(stat => {
            const date = new Date(stat.date);
            
            // Find requests for each threshold on this day
            const threshold51 = result.data.recent_requests.filter(req => 
              req.endpoint.includes('threshold=51') && 
              new Date(req.timestamp).toDateString() === date.toDateString()
            ).length;
            
            const threshold66 = result.data.recent_requests.filter(req => 
              req.endpoint.includes('threshold=66') && 
              new Date(req.timestamp).toDateString() === date.toDateString()
            ).length;
            
            const threshold80 = result.data.recent_requests.filter(req => 
              req.endpoint.includes('threshold=80') && 
              new Date(req.timestamp).toDateString() === date.toDateString()
            ).length;

            return {
              date: date.toLocaleDateString(),
              total_requests: stat.total_requests,
              threshold_51: threshold51,
              threshold_66: threshold66,
              threshold_80: threshold80
            };
          });
          setDailyUsage(formattedDailyStats);
        }

        if (result.data.usage_stats?.endpoints) {
          const allUserAgents = [...new Set(result.data.recent_requests.map(req => req.user_agent))];
          
          const endpointStats = result.data.usage_stats.endpoints.map(endpoint => {
            const thresholdMatch = endpoint.endpoint.match(/threshold=(\d+)/);
            const thresholdNumber = thresholdMatch ? thresholdMatch[1] : 'unknown';
            
            const endpointRequests = result.data.recent_requests.filter(
              req => req.endpoint === endpoint.endpoint
            );

            const userAgentCounts = allUserAgents.reduce((acc, agent) => {
              acc[agent] = 0;
              return acc;
            }, {} as Record<string, number>);

            endpointRequests.forEach(req => {
              userAgentCounts[req.user_agent]++;
            });

            return {
              threshold: `Threshold ${thresholdNumber}`,
              total: endpoint.total_requests,
              ...userAgentCounts
            };
          }).sort((a, b) => {
            const numA = parseInt(a.threshold.split(' ')[1]);
            const numB = parseInt(b.threshold.split(' ')[1]);
            return numA - numB;
          });

          console.log('Processed endpoint stats:', endpointStats);
          setEndpointStats(endpointStats);
        }

        if (result.data.recent_requests) {
          const userAgentCounts = result.data.recent_requests.reduce((acc, req) => {
            acc[req.user_agent] = (acc[req.user_agent] || 0) + 1;
            return acc;
          }, {} as Record<string, number>);

          const userAgentStats = Object.entries(userAgentCounts)
            .map(([user_agent, count]) => ({
              user_agent,
              count
            }))
            .sort((a, b) => b.count - a.count);

          setUserAgentStats(userAgentStats);
        }

        if (result.data.recent_requests) {
          const ipCounts = result.data.recent_requests.reduce((acc, req) => {
            acc[req.ip_address] = (acc[req.ip_address] || 0) + 1;
            return acc;
          }, {} as Record<string, number>);

          const ipStats = Object.entries(ipCounts)
            .map(([ip_address, requests]) => ({
              ip_address,
              requests
            }))
            .sort((a, b) => b.requests - a.requests);

          setIpAddressStats(ipStats);
        }

        if (result.data.recent_requests) {
          const ipThresholdMap = result.data.recent_requests.reduce((acc, req) => {
            const thresholdMatch = req.endpoint.match(/threshold=(\d+)/);
            const threshold = thresholdMatch ? thresholdMatch[1] : 'unknown';
            
            if (!acc[req.ip_address]) {
              acc[req.ip_address] = {
                ip_address: req.ip_address,
                thresholds: {},
                total_requests: 0
              };
            }
            
            acc[req.ip_address].thresholds[threshold] = 
              (acc[req.ip_address].thresholds[threshold] || 0) + 1;
            acc[req.ip_address].total_requests += 1;
            
            return acc;
          }, {} as Record<string, IpThresholdStat>);

          setIpThresholdStats(
            Object.values(ipThresholdMap)
              .sort((a, b) => b.total_requests - a.total_requests)
          );
        }

        if (result.data.recent_requests) {
          const ipUserAgentMap = result.data.recent_requests.reduce((acc, req) => {
            if (!acc[req.ip_address]) {
              acc[req.ip_address] = {
                ip_address: req.ip_address,
                user_agents: {},
                total_requests: 0
              };
            }
            
            acc[req.ip_address].user_agents[req.user_agent] = 
              (acc[req.ip_address].user_agents[req.user_agent] || 0) + 1;
            acc[req.ip_address].total_requests += 1;
            
            return acc;
          }, {} as Record<string, IpUserAgentStat>);

          setIpUserAgentStats(
            Object.values(ipUserAgentMap)
              .sort((a, b) => b.total_requests - a.total_requests)
          );
        }

        setTotalRequests(result.data.usage_stats.total_requests);

      } catch (error) {
        console.error('Error fetching API key details:', error);
      }
    };

    if (apiKey.id) {
      fetchDetails();
    }
  }, [apiKey.id]);

  useEffect(() => {
    if (ipThresholdStats.length > 0) {
      const paginatedStats = ipThresholdStats.map(stat => ({
        ip_address: stat.ip_address,
        total_requests: stat.total_requests,
        threshold_51: stat.thresholds['51'] || 0,
        threshold_66: stat.thresholds['66'] || 0,
        threshold_80: stat.thresholds['80'] || 0
      }));
      
      setPaginatedIpStats(paginatedStats);
      setTotalPages(Math.ceil(paginatedStats.length / pageSize));
    }
  }, [ipThresholdStats, pageSize]);

  const getCurrentData = () => {
    switch (viewMode) {
      case 'detailed':
        return detailedUsage;
      case 'daily':
        return dailyUsage;
      case 'monthly':
        return monthlyUsage;
    }
  };

  const getDataKey = () => {
    switch (viewMode) {
      case 'detailed':
        return 'timestamp';
      case 'daily':
        return 'date';
      case 'monthly':
        return 'month';
    }
  };

  async function handleDelete() {
    setIsDeleting(true);
    try {
      const response = await fetch(
        `/api/dni/keys/${apiKey.id}/delete`,
        {
          method: 'DELETE',
          headers: {
            'Content-Type': 'application/json',
            'X-Admin-Key': process.env.ADMIN_KEY as string,
          },
        }
      );

      if (!response.ok) {
        const errorData = await response.json();
        throw new Error(errorData.error || `HTTP error! status: ${response.status}`);
      }

      toast({
        title: "Success",
        description: "API key deleted successfully",
      });

      onDelete();  // Notify parent component
    } catch (error) {
      console.error('Error deleting API key:', error);
      toast({
        title: "Error",
        description: error instanceof Error ? error.message : "Failed to delete API key",
        variant: "destructive",
      });
    } finally {
      setIsDeleting(false);
      setShowDeleteDialog(false);
    }
  }

  async function handleToggle() {
    setIsToggling(true);
    try {
      const response = await fetch(
        `/api/dni/keys/${apiKey.id}/toggle`,
        {
          method: 'POST',
          headers: {
            'Content-Type': 'application/json',
          },
        }
      );

      if (!response.ok) {
        const errorData = await response.json();
        throw new Error(errorData.message || `HTTP error! status: ${response.status}`);
      }

      const newStatus = !apiKey.isActive;
      
      toast({
        title: "Success",
        description: `API key ${apiKey.isActive ? 'revoked' : 'activated'} successfully`,
      });

      // Call onToggle with the new status
      onToggle(apiKey.id, newStatus);
    } catch (error) {
      console.error('Error toggling API key:', error);
      toast({
        title: "Error",
        description: error instanceof Error ? error.message : "Failed to toggle API key",
        variant: "destructive",
      });
    } finally {
      setIsToggling(false);
    }
  }

  return (
    <div className="space-y-6">
      <div className="flex items-center gap-4">
        <Button variant="ghost" onClick={onBack}>
          <ArrowLeft className="mr-2 h-4 w-4" />
          Back to Dashboard
        </Button>
      </div>

      <div className="grid gap-6 md:grid-cols-2">
        <Card>
          <CardHeader>
            <div className="flex items-center justify-between">
              <CardTitle>API Key Details</CardTitle>
              <div className="flex gap-2">
                <Button 
                  variant={apiKey.isActive ? "destructive" : "default"}
                  size="sm"
                  onClick={handleToggle}
                  disabled={isToggling}
                >
                  {isToggling ? "Processing..." : (apiKey.isActive ? "Revoke Key" : "Activate Key")}
                </Button>
                <Button 
                  variant="destructive" 
                  size="sm"
                  onClick={() => setShowDeleteDialog(true)}
                  disabled={isDeleting}
                >
                  {isDeleting ? "Deleting..." : "Delete Key"}
                </Button>
              </div>
            </div>
          </CardHeader>
          <CardContent>
            <dl className="space-y-4">
              <div>
                <dt className="text-sm font-medium text-gray-500">API Key</dt>
                <dd className="mt-1 font-mono text-sm break-all bg-gray-50 p-2 rounded-md">
                  {apiKey.key}
                </dd>
              </div>
              <div>
                <dt className="text-sm font-medium text-gray-500">Client</dt>
                <dd className="mt-1 text-sm break-words">
                  {apiKey.client}
                </dd>
              </div>
              <div>
                <dt className="text-sm font-medium text-gray-500">Permissions</dt>
                <dd className="mt-1">
                  <div className="flex flex-wrap gap-1">
                    {apiKey.permissions.map((perm) => (
                      <span
                        key={perm}
                        className="rounded-full bg-blue-100 px-2 py-1 text-xs text-blue-800"
                      >
                        {perm}
                      </span>
                    ))}
                  </div>
                </dd>
              </div>
              <div>
                <dt className="text-sm font-medium text-gray-500">Threshold Totals</dt>
                <dd className="mt-2 grid grid-cols-3 gap-2">
                  {thresholdStats.map((stat) => (
                    <div 
                      key={stat.threshold}
                      className="bg-gray-50 p-2 rounded-md text-center"
                    >
                      <div className="text-sm font-medium">{stat.threshold}%</div>
                      <div className="text-sm text-gray-600">{stat.requests.toLocaleString()}</div>
                    </div>
                  ))}
                </dd>
              </div>
              <div>
                <dt className="text-sm font-medium text-gray-500">Last Used</dt>
                <dd className="mt-1 text-sm">
                  {apiKey.lastUsed}
                </dd>
              </div>
              <div>
                <dt className="text-sm font-medium text-gray-500">Total Requests</dt>
                <dd className="mt-1 text-sm">
                  {totalRequests.toLocaleString()}
                </dd>
              </div>
              <div>
                <dt className="text-sm font-medium text-gray-500">Status</dt>
                <dd className="mt-1">
                  <span
                    className={`inline-flex items-center px-2.5 py-0.5 rounded-full text-xs font-medium ${
                      apiKey.isActive 
                        ? 'bg-green-100 text-green-800'
                        : 'bg-red-100 text-red-800'
                    }`}
                  >
                    {apiKey.isActive ? 'Active' : 'Revoked'}
                  </span>
                </dd>
              </div>
            </dl>
          </CardContent>
        </Card>

        <Card>
          <CardHeader>
            <div className="flex items-center justify-between">
              <CardTitle>Top IP Addresses</CardTitle>
              <span className="text-sm text-gray-500">
                Top {ipPageSize} by Request Volume
              </span>
            </div>
          </CardHeader>
          <CardContent>
            <div className="relative overflow-x-auto">
              <table className="w-full text-sm">
                <thead>
                  <tr>
                    <th className="text-left font-medium text-gray-500 pb-2">IP Address</th>
                    <th className="text-right font-medium text-gray-500 pb-2">Requests</th>
                    <th className="text-right font-medium text-gray-500 pb-2">% of Total</th>
                    <th className="w-8"></th>
                  </tr>
                </thead>
                <tbody>
                  {ipAddressStats.slice(0, ipPageSize).map((stat) => [
                    <tr 
                      key={`row-${stat.ip_address}`} 
                      className={`border-t ${selectedIp === stat.ip_address ? 'bg-gray-50' : ''}`}
                    >
                      <td className="py-2 font-mono">
                        <button 
                          onClick={() => setSelectedIp(selectedIp === stat.ip_address ? null : stat.ip_address)}
                          className="hover:text-blue-600 text-left"
                        >
                          {stat.ip_address}
                        </button>
                      </td>
                      <td className="py-2 text-right">{stat.requests.toLocaleString()}</td>
                      <td className="py-2 text-right">
                        {((stat.requests / totalRequests) * 100).toFixed(1)}%
                      </td>
                      <td className="py-2 text-right">
                        <Button
                          variant="ghost"
                          size="sm"
                          onClick={() => setSelectedIp(selectedIp === stat.ip_address ? null : stat.ip_address)}
                        >
                          {selectedIp === stat.ip_address ? '↑' : '↓'}
                        </Button>
                      </td>
                    </tr>,
                    selectedIp === stat.ip_address && (
                      <tr key={`details-${stat.ip_address}`} className="bg-gray-50">
                        <td colSpan={4} className="py-4 px-4">
                          <div className="space-y-4">
                            <div>
                              <h4 className="text-sm font-medium text-gray-700 mb-2">User Agents</h4>
                              <div className="space-y-2">
                                {Object.entries(ipUserAgentStats.find(s => s.ip_address === stat.ip_address)?.user_agents || {})
                                  .sort(([, a], [, b]) => b - a)
                                  .map(([agent, count]) => (
                                    <div key={agent} className="flex justify-between text-sm">
                                      <span className="text-gray-600">{agent}</span>
                                      <span className="text-gray-500">{count} requests</span>
                                    </div>
                                  ))}
                              </div>
                            </div>
                            <div>
                              <h4 className="text-sm font-medium text-gray-700 mb-2">Thresholds Accessed</h4>
                              <div className="space-y-2">
                                {Object.entries(ipThresholdStats.find(s => s.ip_address === stat.ip_address)?.thresholds || {})
                                  .sort(([a], [b]) => Number(a) - Number(b))
                                  .map(([threshold, count]) => (
                                    <div key={threshold} className="flex justify-between text-sm">
                                      <span className="text-gray-600">Threshold {threshold}%</span>
                                      <span className="text-gray-500">{count} requests</span>
                                    </div>
                                  ))}
                              </div>
                            </div>
                          </div>
                        </td>
                      </tr>
                    )
                  ]).flat()}
                </tbody>
              </table>
            </div>
          </CardContent>
        </Card>
      </div>

      <Card>
        <CardHeader>
          <CardTitle>IP Address Usage Details</CardTitle>
        </CardHeader>
        <CardContent>
          <div className="relative overflow-x-auto">
            <table className="w-full text-sm text-left">
              <thead className="text-xs text-gray-700 uppercase bg-gray-50">
                <tr>
                  <th className="px-6 py-3">IP Address</th>
                  <th className="px-6 py-3 text-right">Total Requests</th>
                  <th className="px-6 py-3 text-right">Threshold 51%</th>
                  <th className="px-6 py-3 text-right">Threshold 66%</th>
                  <th className="px-6 py-3 text-right">Threshold 80%</th>
                </tr>
              </thead>
              <tbody>
                {paginatedIpStats
                  .slice((currentPage - 1) * pageSize, currentPage * pageSize)
                  .map((stat) => (
                    <tr key={stat.ip_address} className="bg-white border-b hover:bg-gray-50">
                      <td className="px-6 py-4 font-mono">{stat.ip_address}</td>
                      <td className="px-6 py-4 text-right">{stat.total_requests.toLocaleString()}</td>
                      <td className="px-6 py-4 text-right">{stat.threshold_51.toLocaleString()}</td>
                      <td className="px-6 py-4 text-right">{stat.threshold_66.toLocaleString()}</td>
                      <td className="px-6 py-4 text-right">{stat.threshold_80.toLocaleString()}</td>
                    </tr>
                  ))}
              </tbody>
            </table>
          </div>

          <div className="flex items-center justify-between px-4 py-3 sm:px-6">
            <div className="flex flex-1 justify-between sm:hidden">
              <Button
                variant="outline"
                size="sm"
                onClick={() => setCurrentPage(page => Math.max(1, page - 1))}
                disabled={currentPage === 1}
              >
                Previous
              </Button>
              <Button
                variant="outline"
                size="sm"
                onClick={() => setCurrentPage(page => Math.min(totalPages, page + 1))}
                disabled={currentPage === totalPages}
              >
                Next
              </Button>
            </div>
            <div className="hidden sm:flex sm:flex-1 sm:items-center sm:justify-between">
              <div>
                <p className="text-sm text-gray-700">
                  Showing{' '}
                  <span className="font-medium">
                    {Math.min((currentPage - 1) * pageSize + 1, paginatedIpStats.length)}
                  </span>{' '}
                  to{' '}
                  <span className="font-medium">
                    {Math.min(currentPage * pageSize, paginatedIpStats.length)}
                  </span>{' '}
                  of{' '}
                  <span className="font-medium">{paginatedIpStats.length}</span>{' '}
                  results
                </p>
              </div>
              <div>
                <nav className="isolate inline-flex -space-x-px rounded-md shadow-sm" aria-label="Pagination">
                  <Button
                    variant="outline"
                    size="sm"
                    className="rounded-l-md"
                    onClick={() => setCurrentPage(page => Math.max(1, page - 1))}
                    disabled={currentPage === 1}
                  >
                    <ChevronLeft className="h-4 w-4" />
                  </Button>
                  {Array.from({ length: totalPages }, (_, i) => i + 1)
                    .filter(page => {
                      const distance = Math.abs(page - currentPage);
                      return distance === 0 || distance === 1 || page === 1 || page === totalPages;
                    })
                    .map((page, index, array) => {
                      if (index > 0 && array[index - 1] !== page - 1) {
                        return [
                          <Button
                            key={`ellipsis-${page}`}
                            variant="outline"
                            size="sm"
                            disabled
                            className="cursor-default"
                          >
                            ...
                          </Button>,
                          <Button
                            key={page}
                            variant={currentPage === page ? "default" : "outline"}
                            size="sm"
                            onClick={() => setCurrentPage(page)}
                          >
                            {page}
                          </Button>
                        ];
                      }
                      return (
                        <Button
                          key={page}
                          variant={currentPage === page ? "default" : "outline"}
                          size="sm"
                          onClick={() => setCurrentPage(page)}
                        >
                          {page}
                        </Button>
                      );
                    })}
                  <Button
                    variant="outline"
                    size="sm"
                    className="rounded-r-md"
                    onClick={() => setCurrentPage(page => Math.min(totalPages, page + 1))}
                    disabled={currentPage === totalPages}
                  >
                    <ChevronRight className="h-4 w-4" />
                  </Button>
                </nav>
              </div>
            </div>
          </div>
        </CardContent>
      </Card>

      <Card>
        <CardHeader>
          <div className="flex items-center justify-between">
            <CardTitle>Usage Statistics</CardTitle>
            <div className="space-x-2">
              <Button
                variant={viewMode === 'detailed' ? 'default' : 'outline'}
                size="sm"
                onClick={() => setViewMode('detailed')}
              >
                Detailed
              </Button>
              <Button
                variant={viewMode === 'daily' ? 'default' : 'outline'}
                size="sm"
                onClick={() => setViewMode('daily')}
              >
                Daily
              </Button>
              <Button
                variant={viewMode === 'monthly' ? 'default' : 'outline'}
                size="sm"
                onClick={() => setViewMode('monthly')}
              >
                Monthly
              </Button>
            </div>
          </div>
        </CardHeader>
        <CardContent className="pt-4">
          <div className="h-[400px] w-full">
            {getCurrentData().length > 0 ? (
              <ResponsiveContainer width="100%" height="100%">
                <LineChart 
                  data={getCurrentData()}
                  margin={{ top: 20, right: 20, left: 0, bottom: 70 }}
                >
                  <defs>
                    <linearGradient id="totalRequests" x1="0" y1="0" x2="0" y2="1">
                      <stop offset="5%" stopColor="hsl(200, 70%, 50%)" stopOpacity={0.2}/>
                      <stop offset="95%" stopColor="hsl(200, 70%, 50%)" stopOpacity={0}/>
                    </linearGradient>
                    <linearGradient id="threshold51" x1="0" y1="0" x2="0" y2="1">
                      <stop offset="5%" stopColor="hsl(130, 70%, 50%)" stopOpacity={0.2}/>
                      <stop offset="95%" stopColor="hsl(130, 70%, 50%)" stopOpacity={0}/>
                    </linearGradient>
                    <linearGradient id="threshold66" x1="0" y1="0" x2="0" y2="1">
                      <stop offset="5%" stopColor="hsl(50, 70%, 50%)" stopOpacity={0.2}/>
                      <stop offset="95%" stopColor="hsl(50, 70%, 50%)" stopOpacity={0}/>
                    </linearGradient>
                    <linearGradient id="threshold80" x1="0" y1="0" x2="0" y2="1">
                      <stop offset="5%" stopColor="hsl(0, 70%, 50%)" stopOpacity={0.2}/>
                      <stop offset="95%" stopColor="hsl(0, 70%, 50%)" stopOpacity={0}/>
                    </linearGradient>
                  </defs>
                  
                  <XAxis
                    dataKey={getDataKey()}
                    stroke="#888888"
                    fontSize={11}
                    tickLine={false}
                    axisLine={false}
                    angle={viewMode === 'detailed' ? 45 : 30}
                    textAnchor="start"
                    height={80}
                    interval={viewMode === 'detailed' ? 2 : 0}
                    tick={NumberTick}
                  />
                  <YAxis
                    stroke="#888888"
                    fontSize={12}
                    tickLine={false}
                    axisLine={false}
                    tick={NumberTick}
                    label={{ 
                      value: 'Requests', 
                      angle: -90, 
                      position: 'insideLeft',
                      style: { fill: '#666' }
                    }}
                  />
                  <Tooltip
                    contentStyle={{
                      backgroundColor: 'rgba(255, 255, 255, 0.95)',
                      border: '1px solid #ccc',
                      borderRadius: '6px',
                      padding: '8px'
                    }}
                    labelStyle={{
                      fontWeight: 'bold',
                      marginBottom: '4px'
                    }}
                    labelFormatter={(label) => {
                      switch (viewMode) {
                        case 'detailed':
                          return `Time: ${label}`;
                        case 'daily':
                          return `Date: ${label}`;
                        case 'monthly':
                          return `Month: ${label}`;
                      }
                    }}
                  />
                  <Legend 
                    verticalAlign="top"
                    height={50}
                    content={({ payload }) => (
                      <div className="flex flex-wrap gap-2 justify-center mb-2 max-w-full px-4">
                        {payload?.map((entry) => (
                          <div 
                            key={entry.value} 
                            className="flex items-center gap-2 bg-white px-2 py-1 rounded-md shadow-sm"
                          >
                            <div 
                              className="w-3 h-3 rounded-full flex-shrink-0"
                              style={{ backgroundColor: entry.color }}
                            />
                            <span className="text-xs text-gray-600">
                              {entry.value === 'total_requests' ? 'Total Requests' : 
                               entry.value === 'threshold_51' ? 'Threshold 51%' :
                               entry.value === 'threshold_66' ? 'Threshold 66%' :
                               entry.value === 'threshold_80' ? 'Threshold 80%' : 
                               entry.value}
                            </span>
                          </div>
                        ))}
                      </div>
                    )}
                  />
                  <Line
                    type="monotone"
                    dataKey="total_requests"
                    stroke="hsl(200, 70%, 50%)"
                    strokeWidth={2.5}
                    dot={viewMode === 'detailed' ? {
                      r: 4,
                      strokeWidth: 2,
                      fill: 'white'
                    } : false}
                    activeDot={{
                      r: 6,
                      strokeWidth: 2,
                      fill: 'white'
                    }}
                    name="Total Requests"
                    fill="url(#totalRequests)"
                  />
                  <Line
                    type="monotone"
                    dataKey="threshold_51"
                    stroke="hsl(130, 70%, 50%)"
                    strokeWidth={2.5}
                    dot={viewMode === 'detailed' ? {
                      r: 4,
                      strokeWidth: 2,
                      fill: 'white'
                    } : false}
                    activeDot={{
                      r: 6,
                      strokeWidth: 2,
                      fill: 'white'
                    }}
                    name="Threshold 51%"
                    fill="url(#threshold51)"
                  />
                  <Line
                    type="monotone"
                    dataKey="threshold_66"
                    stroke="hsl(50, 70%, 50%)"
                    strokeWidth={2.5}
                    dot={viewMode === 'detailed' ? {
                      r: 4,
                      strokeWidth: 2,
                      fill: 'white'
                    } : false}
                    activeDot={{
                      r: 6,
                      strokeWidth: 2,
                      fill: 'white'
                    }}
                    name="Threshold 66%"
                    fill="url(#threshold66)"
                  />
                  <Line
                    type="monotone"
                    dataKey="threshold_80"
                    stroke="hsl(0, 70%, 50%)"
                    strokeWidth={2.5}
                    dot={viewMode === 'detailed' ? {
                      r: 4,
                      strokeWidth: 2,
                      fill: 'white'
                    } : false}
                    activeDot={{
                      r: 6,
                      strokeWidth: 2,
                      fill: 'white'
                    }}
                    name="Threshold 80%"
                    fill="url(#threshold80)"
                  />
                </LineChart>
              </ResponsiveContainer>
            ) : (
              <div className="flex h-full items-center justify-center text-gray-500">
                No usage data available
              </div>
            )}
          </div>
        </CardContent>
      </Card>

      <Card>
        <CardHeader>
          <CardTitle>User Agent Distribution</CardTitle>
        </CardHeader>
        <CardContent>
          <div className="relative overflow-x-auto">
            <table className="w-full text-sm">
              <thead>
                <tr>
                  <th className="text-left font-medium text-gray-500 pb-2">User Agent</th>
                  <th className="text-right font-medium text-gray-500 pb-2">Requests</th>
                  <th className="text-right font-medium text-gray-500 pb-2">% of Total</th>
                </tr>
              </thead>
              <tbody>
                {userAgentStats.map((stat) => (
                  <tr 
                    key={stat.user_agent}
                    className="border-t"
                  >
                    <td className="py-2 pr-4">
                      <div className="font-mono text-sm break-all">
                        {stat.user_agent}
                      </div>
                    </td>
                    <td className="py-2 text-right">
                      {stat.count.toLocaleString()}
                    </td>
                    <td className="py-2 text-right">
                      {((stat.count / totalRequests) * 100).toFixed(1)}%
                    </td>
                  </tr>
                ))}
              </tbody>
            </table>
          </div>
        </CardContent>
      </Card>

      <Card>
        <CardHeader>
          <CardTitle>Endpoint Usage by User Agent</CardTitle>
        </CardHeader>
        <CardContent>
          <div className="relative overflow-x-auto">
            <table className="w-full text-sm">
              <thead>
                <tr>
                  <th className="text-left font-medium text-gray-500 pb-2">Threshold</th>
                  <th className="text-right font-medium text-gray-500 pb-2">Total</th>
                  {Object.keys(endpointStats[0] || {})
                    .filter(key => key !== 'threshold' && key !== 'total')
                    .map(userAgent => (
                      <th 
                        key={userAgent} 
                        className="text-right font-medium text-gray-500 pb-2 px-4"
                      >
                        <div className="font-mono text-xs break-all">
                          {userAgent}
                        </div>
                      </th>
                    ))}
                </tr>
              </thead>
              <tbody>
                {endpointStats.map((stat) => (
                  <tr key={stat.threshold} className="border-t">
                    <td className="py-2">{stat.threshold}</td>
                    <td className="py-2 text-right">{stat.total.toLocaleString()}</td>
                    {Object.keys(stat)
                      .filter(key => key !== 'threshold' && key !== 'total')
                      .map(userAgent => (
                        <td key={userAgent} className="py-2 text-right px-4">
                          {stat[userAgent].toLocaleString()}
                          <div className="text-xs text-gray-500">
                            {((stat[userAgent] / stat.total) * 100).toFixed(1)}%
                          </div>
                        </td>
                      ))}
                  </tr>
                ))}
              </tbody>
            </table>
          </div>
        </CardContent>
      </Card>

      <AlertDialog open={showDeleteDialog} onOpenChange={setShowDeleteDialog}>
        <AlertDialogContent>
          <AlertDialogHeader>
            <AlertDialogTitle>Are you sure?</AlertDialogTitle>
            <AlertDialogDescription>
              This action cannot be undone. This will permanently delete the API key
              and all associated data.
            </AlertDialogDescription>
          </AlertDialogHeader>
          <AlertDialogFooter>
            <AlertDialogCancel disabled={isDeleting}>Cancel</AlertDialogCancel>
            <AlertDialogAction
              onClick={handleDelete}
              disabled={isDeleting}
              className="bg-red-600 hover:bg-red-700"
            >
              {isDeleting ? "Deleting..." : "Delete"}
            </AlertDialogAction>
          </AlertDialogFooter>
        </AlertDialogContent>
      </AlertDialog>
    </div>
  )
} 