import {  Copy, Check } from 'lucide-react'
import { Button } from '@/components/ui/button'
import { Card, CardContent, CardDescription, CardHeader, CardTitle } from '@/components/ui/card'
import {
  Table,
  TableBody,
  TableCell,
  TableHead,
  TableHeader,
  TableRow,
} from '@/components/ui/table'
import { CreateApiKeyDialog } from './CreateApiKeyDialog'
import { useState } from 'react'
import { useToast } from '@/components/ui/use-toast'
import { cn } from '@/lib/utils'

interface ApiKeysTableProps {
  apiKeys: ApiKey[]
  onCreateKey: (data: { client: string; permissions: string[] }) => void
  onRevokeKey?: (id: number) => void
  onSelectKey?: (key: ApiKey) => void
}

interface ApiKey {
  id: number
  key: string
  client: string
  permissions: string[]
  requests: Record<string, number>
  lastUsed: string
  is_active: boolean
}

function formatDate(dateString: string | null): string {
  if (!dateString) return 'Never'
  
  const date = new Date(dateString)
  
  // Format: YYYY-MM-DD, HH:mm:ss
  return date.toLocaleString('en-GB', {
    year: 'numeric',
    month: '2-digit',
    day: '2-digit',
    hour: '2-digit',
    minute: '2-digit',
    second: '2-digit',
    hour12: false,
  }).replace(/(\d+)\/(\d+)\/(\d+), /, '$3-$2-$1, ')
}

export function ApiKeysTable({ apiKeys, onCreateKey, onRevokeKey, onSelectKey }: ApiKeysTableProps) {
  const [copiedKey, setCopiedKey] = useState<string | null>(null)
  const [isRevoking, setIsRevoking] = useState<number | null>(null)
  const { toast } = useToast()

  const handleRowClick = (e: React.MouseEvent, key: ApiKey) => {
    if ((e.target as HTMLElement).closest('button')) {
      e.stopPropagation()
      return
    }
    handleKeyClick(key)
  }

  const truncateKey = (key: string) => {
    return `${key.substring(0, 8)}...${key.substring(key.length - 8)}`
  }

  const copyToClipboard = async (key: string) => {
    try {
      await navigator.clipboard.writeText(key)
      setCopiedKey(key)
      toast({
        title: "Copied!",
        description: "API key copied to clipboard",
        duration: 2000,
      })
      setTimeout(() => setCopiedKey(null), 2000)
    } catch (err) {
      console.error('Error copying API key:', err)
      toast({
        title: "Error",
        description: "Failed to copy API key",
        variant: "destructive",
      })
    }
  }

  const handleToggle = async (keyId: number, isActive: boolean) => {
    try {
      setIsRevoking(keyId)
      const response = await fetch(`/api/dni/keys/${keyId}/toggle`, {
        method: 'POST',
        headers: {
          'Content-Type': 'application/json',
        },
      })

      const data = await response.json()

      if (!response.ok) {
        throw new Error(data.message || 'Failed to update API key status')
      }

      if (!data.success) {
        throw new Error(data.message || 'Failed to update API key status')
      }

      toast({
        title: "Success",
        description: data.message || `API key ${isActive ? 'deactivated' : 'activated'} successfully`,
        variant: "default",
      })

      // Trigger refresh of API keys
      onRevokeKey?.(keyId)

    } catch (error) {
      console.error('Error toggling key:', error)
      toast({
        title: "Error",
        description: error instanceof Error ? error.message : 'Failed to update API key status',
        variant: "destructive",
        duration: 5000,
      })
    } finally {
      setIsRevoking(null)
    }
  }

  const handleKeyClick = (key: ApiKey) => {
    const formattedKey = {
      ...key,
      isActive: key.is_active,
      permissions: key.permissions.map(perm => 
        perm.startsWith('threshold_') 
          ? `DNI+${perm.replace('threshold_', '')}` 
          : perm
      ),
      requests: {
        'DNI': key.requests?.DNI || 0,
        'DNI+51': key.requests?.['DNI+51'] || 0,
        'DNI+66': key.requests?.['DNI+66'] || 0,
        'DNI+80': key.requests?.['DNI+80'] || 0,
        'Total': key.requests?.Total || 0
      }
    };
    
    console.log('Passing key to details:', formattedKey);
    onSelectKey?.(formattedKey);
  };

  return (
    <Card>
      <CardHeader className="flex flex-row items-center justify-between">
        <div>
          <CardTitle>API Keys</CardTitle>
          <CardDescription>Manage access to different DNI lists</CardDescription>
        </div>
        <CreateApiKeyDialog onCreateKey={onCreateKey} />
      </CardHeader>
      <CardContent>
        <Table>
          <TableHeader>
            <TableRow>
              <TableHead>API Key</TableHead>
              <TableHead>Client</TableHead>
              <TableHead>Permitted Lists</TableHead>
              <TableHead>Total Requests</TableHead>
              <TableHead>Last Used</TableHead>
              <TableHead>Actions</TableHead>
            </TableRow>
          </TableHeader>
          <TableBody>
            {apiKeys.map((key) => (
              <TableRow 
                key={key.id}
                className="cursor-pointer hover:bg-gray-50"
                onClick={(e) => handleRowClick(e, key)}
              >
                <TableCell>
                  <div className="flex items-center gap-2">
                    <code className="rounded bg-muted px-2 py-1">
                      {truncateKey(key.key)}
                    </code>
                    <Button
                      variant="ghost"
                      size="sm"
                      onClick={(e) => {
                        e.stopPropagation()
                        copyToClipboard(key.key)
                      }}
                    >
                      {copiedKey === key.key ? (
                        <Check className="h-4 w-4 text-green-500" />
                      ) : (
                        <Copy className="h-4 w-4" />
                      )}
                    </Button>
                  </div>
                </TableCell>
                <TableCell>{key.client}</TableCell>
                <TableCell>
                  <div className="flex gap-1">
                    {key.permissions.map((perm) => (
                      <span
                        key={perm}
                        className="rounded-full bg-blue-100 px-2 py-1 text-xs text-blue-800"
                      >
                        {perm}
                      </span>
                    ))}
                  </div>
                </TableCell>
                <TableCell>
                  <div className="space-y-1">
                    <div className="font-medium text-sm">
                      {key.requests.Total || 0}
                    </div>
                    {Object.entries(key.requests)
                      .filter(([list]) => !list.startsWith('threshold_') && list !== 'Total')
                      .map(([list, count]) => (
                        <div key={list} className="text-sm text-gray-500">
                          {list}: {count}
                        </div>
                    ))}
                  </div>
                </TableCell>
                <TableCell>{formatDate(key.lastUsed)}</TableCell>
                <TableCell>
                  <Button
                    variant="ghost"
                    size="sm"
                    onClick={(e) => {
                      e.stopPropagation()
                      handleToggle(key.id, key.is_active)
                    }}
                    disabled={isRevoking === key.id}
                    className={cn(
                      key.is_active 
                        ? "text-red-600 hover:text-red-700 hover:bg-red-50" 
                        : "text-green-600 hover:text-green-700 hover:bg-green-50"
                    )}
                  >
                    {isRevoking === key.id ? (
                      key.is_active ? "Revoking..." : "Activating..."
                    ) : (
                      key.is_active ? "Revoke" : "Activate"
                    )}
                  </Button>
                </TableCell>
              </TableRow>
            ))}
          </TableBody>
        </Table>
      </CardContent>
    </Card>
  )
} 