"use client"

import { useState } from 'react'
import { Plus } from 'lucide-react'
import { Button } from '@/components/ui/button'
import {
  Dialog,
  DialogContent,
  DialogDescription,
  DialogFooter,
  DialogHeader,
  DialogTitle,
  DialogTrigger,
} from '@/components/ui/dialog'
import { Input } from '@/components/ui/input'
import { Label } from '@/components/ui/label'
import { ApiKey, CreateApiKeyRequest, } from '@/types/api'
import { useToast } from '@/components/ui/use-toast'
import { v4 as uuidv4 } from 'uuid'

interface CreateApiKeyDialogProps {
  onCreateKey: (data: {
    client: string
    permissions: string[]
  }) => void
}

const PERMISSION_MAP = {
  'DNI+51': 'threshold_51',
  'DNI+66': 'threshold_66',
  'DNI+80': 'threshold_80'
}

export function CreateApiKeyDialog({ onCreateKey }: CreateApiKeyDialogProps) {
  const [open, setOpen] = useState(false)
  const [client, setClient] = useState('')
  const [selectedPermissions, setSelectedPermissions] = useState<string[]>(['DNI+51', 'DNI+66', 'DNI+80'])
  const [isLoading, setIsLoading] = useState(false)
  const { toast } = useToast()

  const handleSubmit = async (e: React.FormEvent) => {
    e.preventDefault()
    setIsLoading(true)

    try {
      const apiPermissions = selectedPermissions.map(perm => PERMISSION_MAP[perm as keyof typeof PERMISSION_MAP])

      const payload: CreateApiKeyRequest = {
        description: client,
        permissions: apiPermissions
      }

      console.log('Sending request payload:', payload)

      let response: Response
      try {
        response = await fetch('/api/dni', {
          method: 'POST',
          headers: {
            'Content-Type': 'application/json',
          },
          body: JSON.stringify(payload),
        })

        console.log('Response status:', response.status)

      } catch (networkError) {
        console.error('Network error:', networkError)
        throw new Error('Failed to connect to the server. Please try again.')
      }

      let data
      try {
        data = await response.json()
        console.log('Response data:', data)
      } catch (parseError) {
        console.error('Response parsing error:', parseError)
        throw new Error('Invalid response from server.')
      }

      if (!response.ok || !data.success) {
        throw new Error(data.message || `Error: ${response.status}`)
      }

      // Success case
      const newKey: ApiKey = {
        id: uuidv4(),
        key: data.key,
        client: data.description,
        permissions: data.permissions.map((perm: string) => 
          Object.entries(PERMISSION_MAP).find(([_, value]) => value === perm)?.[0] || perm
        ),
        requests: {
          'DNI': 0,
          'DNI+51': 0,
          'DNI+66': 0,
          'DNI+80': 0,
          Total: 0
        },
        lastUsed: new Date().toISOString().split('T')[0],
        is_active: false
      }

      onCreateKey({
        client: newKey.client,
        permissions: newKey.permissions,
      })

      toast({
        title: "Success",
        description: `API key created: ${data.key}`,
        variant: "default",
      })

      setOpen(false)
      setClient('')
      setSelectedPermissions(['DNI+51', 'DNI+66', 'DNI+80'])

    } catch (error) {
      console.error('Error details:', error)
      
      let errorMessage: string
      if (error instanceof Error) {
        errorMessage = error.message
      } else if (error && typeof error === 'object' && 'message' in error) {
        errorMessage = String(error.message)
      } else {
        errorMessage = 'An unexpected error occurred'
      }

      toast({
        title: "Error Creating API Key",
        description: errorMessage,
        variant: "destructive",
        duration: 10000,
      })
    } finally {
      setIsLoading(false)
    }
  }

  const togglePermission = (permission: string) => {
    setSelectedPermissions(prev =>
      prev.includes(permission)
        ? prev.filter(p => p !== permission)
        : [...prev, permission]
    )
  }

  const availablePermissions = ['DNI+51', 'DNI+66', 'DNI+80']

  return (
    <Dialog open={open} onOpenChange={setOpen}>
      <DialogTrigger asChild>
        <Button>
          <Plus className="mr-2 h-4 w-4" />
          Create New Key
        </Button>
      </DialogTrigger>
      <DialogContent className="sm:max-w-[425px]">
        <form onSubmit={handleSubmit}>
          <DialogHeader>
            <DialogTitle>Create API Key</DialogTitle>
            <DialogDescription>
              Create a new API key with specific permissions for a client.
            </DialogDescription>
          </DialogHeader>
          <div className="grid gap-4 py-4">
            <div className="grid gap-2">
              <Label htmlFor="client">Client Name</Label>
              <Input
                id="client"
                value={client}
                onChange={(e) => setClient(e.target.value)}
                placeholder="Enter client name"
                required
                disabled={isLoading}
              />
            </div>
            <div className="grid gap-2">
              <Label>Permissions</Label>
              <div className="flex flex-wrap gap-2">
                {availablePermissions.map((perm) => (
                  <Button
                    key={perm}
                    type="button"
                    variant={selectedPermissions.includes(perm) ? "default" : "outline"}
                    onClick={() => togglePermission(perm)}
                    className="h-8"
                    disabled={isLoading}
                  >
                    {perm}
                  </Button>
                ))}
              </div>
            </div>
          </div>
          <DialogFooter>
            <Button 
              type="submit" 
              disabled={isLoading || !client || selectedPermissions.length === 0}
            >
              {isLoading ? "Creating..." : "Create Key"}
            </Button>
          </DialogFooter>
        </form>
      </DialogContent>
    </Dialog>
  )
} 